@@ -16,12 +16,15 @@ class browser:
     wait_timeout = 30
 
     def create_firefox(self, page_load_timeout, wait_timeout, add_log = True):
-        self.create_browser(page_load_timeout, wait_timeout, False, add_log)
+        self.create_browser(page_load_timeout, wait_timeout, False, None, add_log)
 
     def create_chrome(self, page_load_timeout, wait_timeout, add_log = True):
-        self.create_browser(page_load_timeout, wait_timeout, True, add_log)
+        opts = webdriver.ChromeOptions()
+        opts.add_argument('--no-sandbox')
+        opts.add_argument('--disable-dev-shm-usage')
+        self.create_browser(page_load_timeout, wait_timeout, True, opts, add_log)
 
-    def create_browser(self, page_load_timeout, wait_timeout, chrome, add_log = True):
+    def create_browser(self, page_load_timeout, wait_timeout, chrome, options, add_log = True):
         if not sys.platform == 'win32':
             self.add_and_print_log('Creating display', add_log)
             self.display = Display(visible=0, size=(1920, 768))
@@ -29,7 +32,7 @@ class browser:
         self.add_and_print_log('Creating browser', add_log)
 
         if (chrome):
-            self.driver = webdriver.Chrome()
+            self.driver = webdriver.Chrome(options)
         else:
             self.driver = webdriver.Firefox()
 
